import { z } from 'zod';

declare const RUNTIME_ENVIRONMENTS: readonly ["browser", "bun", "deno", "dom", "edge", "happy-dom", "jsdom", "node", "web-worker"];
type RuntimeEnvironment = (typeof RUNTIME_ENVIRONMENTS)[number];
declare const RUNTIME_ENVIRONMENT_SCHEMA: z.ZodEnum<["browser", "bun", "deno", "dom", "edge", "happy-dom", "jsdom", "node", "web-worker"]>;
/**
 * @see {@link https://bun.sh/docs/api/globals}
 */
declare const IN_BUN: boolean;
/**
 * @see {@link https://deno.land/manual@v1.31.1/runtime#deno-global}
 */
declare const IN_DENO: boolean;
/**
 * Detects if the DOM is available.
 */
declare const IN_DOM: boolean;
/**
 * @see {@link https://edge-runtime.vercel.app/features/available-apis#addressing-the-runtime}
 */
declare const IN_EDGE: boolean;
/**
 * @see {@link https://github.com/jsdom/jsdom}
 */
declare const IN_JSDOM: boolean;
/**
 * @see {@link https://github.com/capricorn86/happy-dom/discussions/481}
 */
declare const IN_HAPPY_DOM: boolean;
/**
 * @see {@link https://nodejs.org/dist/latest-v18.x/docs/api/process.html#process}
 */
declare const IN_NODE: boolean;
/**
 * Detect if is running in browser, and is not in a browser emulator (e.g. jsdom or Happy DOM)
 */
declare const IN_BROWSER: boolean;
/**
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/Web_Workers_API/Using_web_workers}
 */
declare const IN_WEB_WORKER: boolean;
/**
 * Receive the name _(in lowercase)_ of the currently running JavaScript environment.
 */
declare function getRuntimeEnvironmentName(): RuntimeEnvironment;
declare function validateRuntimeEnvironmentName(name: string): asserts name is RuntimeEnvironment;
declare function isValidRuntimeEnvironmentName(name: string): name is RuntimeEnvironment;

export { IN_BROWSER, IN_BUN, IN_DENO, IN_DOM, IN_EDGE, IN_HAPPY_DOM, IN_JSDOM, IN_NODE, IN_WEB_WORKER, RUNTIME_ENVIRONMENTS, RUNTIME_ENVIRONMENT_SCHEMA, RuntimeEnvironment, getRuntimeEnvironmentName, isValidRuntimeEnvironmentName, validateRuntimeEnvironmentName };
